@@ -1,4 +1,4 @@
-# @(#)Ident: Bob.pm 2013-04-01 14:34 pjf ;
+# @(#)Ident: Bob.pm 2013-04-03 17:46 pjf ;
 
 package Bob;
 
@@ -10,7 +10,7 @@ sub whimper { print {*STDOUT} $_[ 0 ]."\n"; exit 0 }
 
 BEGIN { my $reason; $reason = CPANTesting::should_abort and whimper $reason; }
 
-use version; our $VERSION = qv( '1.9' );
+use version; our $VERSION = qv( '1.11' );
 
 use File::Spec::Functions qw(catfile);
 use Module::Build;
@@ -41,7 +41,8 @@ sub new {
         notes              => __get_notes( $p ),
         recommends         => $p->{recommends},
         requires           => $p->{requires},
-        sign               => defined $p->{sign} ? $p->{sign} : 1, );
+        sign               => defined $p->{sign} ? $p->{sign} : 1,
+        share_dir          => __get_share_dir( $p ), );
 }
 
 # Private functions
@@ -93,6 +94,8 @@ sub __get_notes {
    $notes->{is_cpan_testing  } = CPANTesting::is_testing();
    # Add a note to stop CPAN testing if requested in Build.PL
    $notes->{stop_tests       } = CPANTesting::test_exceptions( $p );
+   $notes->{url_prefix       } = defined $p->{url_prefix} ? $p->{url_prefix}
+                               : q(https://metacpan.org/module/);
    $notes->{version          } = $VERSION;
    return $notes;
 }
@@ -125,6 +128,12 @@ sub __get_resources {
    return { resources => $resources };
 }
 
+sub __get_share_dir {
+   my $p = shift; defined $p->{share_dir} and return $p->{share_dir};
+
+   return -d q(share) ? q(share) : undef;
+}
+
 sub __get_svn_repository {
    return (grep { ! m{ \A file: }mx }
            (split q( ), (grep { m{ \A URL: }mx }
