@@ -1,23 +1,23 @@
-# @(#)$Id: Constants.pm 450 2013-04-29 17:11:07Z pjf $
+# @(#)$Ident: Constants.pm 2013-04-30 21:41 pjf ;
 
 package File::DataClass::Constants;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.17.%d', q$Rev: 450 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.18.%d', q$Rev: 4 $ =~ /\d+/gmx );
 
 use Moose;
 use MooseX::ClassAttribute;
 use MooseX::Types -declare => [ q(ExceptionTC) ];
 use MooseX::Types::Moose       qw(ClassName);
-use File::DataClass::Exception;
+use File::DataClass::Exception::Simple;
 
 subtype ExceptionTC, as ClassName,
    where   { $_->can( q(throw) ) },
    message { "Class ${_} is not loaded or has no throw method" };
 
 class_has 'Exception_Class' => is => 'rw', isa => ExceptionTC,
-   default                  => q(File::DataClass::Exception);
+   default                  => q(File::DataClass::Exception::Simple);
 
 my @constants;
 
@@ -68,7 +68,7 @@ File::DataClass::Constants - Definitions of constant values
 
 =head1 Version
 
-0.17.$Rev: 450 $
+This document describes version v0.18.$Rev: 4 $
 
 =head1 Synopsis
 
